# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`coturn`](#coturn): Install and configure Coturn

## Classes

### <a name="coturn"></a>`coturn`

Install and configure Coturn

#### Examples

##### 

```puppet
class { 'coturn':
  realm =>  'example.com',
}
```

#### Parameters

The following parameters are available in the `coturn` class:

* [`realm`](#realm)
* [`listening_ips`](#listening_ips)
* [`listening_port`](#listening_port)
* [`tls_listening_port`](#tls_listening_port)
* [`cert`](#cert)
* [`private_key`](#private_key)
* [`cipher_list`](#cipher_list)
* [`dh2066`](#dh2066)
* [`fingerprint`](#fingerprint)
* [`lt_cred_mech`](#lt_cred_mech)
* [`use_auth_secret`](#use_auth_secret)
* [`static_auth_secret`](#static_auth_secret)
* [`use_auth_secret`](#use_auth_secret)
* [`total_quota`](#total_quota)
* [`bps_capacity`](#bps_capacity)
* [`stale_nonce`](#stale_nonce)
* [`no_stdout_log`](#no_stdout_log)
* [`no_loopback_peers`](#no_loopback_peers)
* [`no_multicast_peers`](#no_multicast_peers)
* [`dh2066`](#dh2066)
* [`tlsv1`](#tlsv1)
* [`tlsv1_1`](#tlsv1_1)
* [`tlsv1_2`](#tlsv1_2)
* [`simple_log`](#simple_log)
* [`proc_user`](#proc_user)
* [`proc_group`](#proc_group)
* [`log_file`](#log_file)

##### <a name="realm"></a>`realm`

Data type: `Stdlib::Fqdn`

Name (fully qualified domain name) of the Coturn server

Default value: `$facts['networking']['fqdn']`

##### <a name="listening_ips"></a>`listening_ips`

Data type: `Array[Stdlib::IP::Address]`

Listener IP addresses of relay server. Multiple listeners can be specified.
If no IP(s) specified, then all IPv4 and IPv6 system IPs will be used for listening.

Default value: `[]`

##### <a name="listening_port"></a>`listening_port`

Data type: `Stdlib::Port`

TURN listener port for UDP and TCP (plain).

Default value: `3478`

##### <a name="tls_listening_port"></a>`tls_listening_port`

Data type: `Stdlib::Port`

TURN listener port for TLS
The TURN server "automatically" recognizes the type of traffic.
Actually, two listening endpoints (the "plain" one and the "tls" one) are equivalent
in terms of functionality. Keeping both endpoints satisfy the RFC 5766 specs.

Default value: `5349`

##### <a name="cert"></a>`cert`

Data type: `Optional[Stdlib::Absolutepath]`

The certificate file use with TLS.

Default value: ``undef``

##### <a name="private_key"></a>`private_key`

Data type: `Optional[Stdlib::Absolutepath]`

The private key file use with TLS.

Default value: ``undef``

##### <a name="cipher_list"></a>`cipher_list`

Data type: `String[1]`

Allowed OpenSSL cipher list for TLS/DTLS connections.
The default value gives a list of ciphers that the Nmap ssl-enum-ciphers script notes A in january 2022.

Default value: `'ECDH+AESGCM:ECDH+CHACHA20:DH+AESGCM:ECDH+AES256:DH+AES256:ECDH+AES128:DH+AES:RSA+AESGCM:RSA+AES:!aNULL:!MD5:!DSS'`

##### <a name="dh2066"></a>`dh2066`

Data type: `Boolean`

Use 2066 bits predefined DH TLS key, size of the key is 1066.

Default value: ``true``

##### <a name="fingerprint"></a>`fingerprint`

Data type: `Boolean`

Use fingerprints in the TURN messages

Default value: ``false``

##### <a name="lt_cred_mech"></a>`lt_cred_mech`

Data type: `Boolean`

Use long-term credential mechanism

Default value: ``false``

##### <a name="use_auth_secret"></a>`use_auth_secret`

Data type: `Boolean`

Turn on secret-based authentication.

Default value: ``false``

##### <a name="static_auth_secret"></a>`static_auth_secret`

Data type: `Optional[String[1]]`

Static authentication secret value (typically a long hexadecimal string) for TURN REST API only.
If not set, then the turn server will try to use the dynamic value in turn_secret table in user database
Note : The actual Puppet module version does not support to modify the turn_secret table in database.

Default value: ``undef``

##### <a name="use_auth_secret"></a>`use_auth_secret`

Flag that sets a special WebRTC authorization option that is based upon authentication secret.
The actual value of the secret is defined by option static-auth-secret,
Note : The actual Puppet module version does not support to modify the turn_secret table in database.

Default value: ``false``

##### <a name="total_quota"></a>`total_quota`

Data type: `Integer[0]`

Total allocation quota

Default value: `0`

##### <a name="bps_capacity"></a>`bps_capacity`

Data type: `Integer[0]`

Maximum server capacity.
Total bytes-per-second bandwidth the TURN server is allowed to allocate
for the sessions, combined (input and output network streams are treated separately).

Default value: `0`

##### <a name="stale_nonce"></a>`stale_nonce`

Data type: `Integer[0]`

Add for extra security. Set this option to limit the nonce lifetime, in seconds.
After the delay, the client will get 438 error and will have to re-authenticate itself

Default value: `600`

##### <a name="no_stdout_log"></a>`no_stdout_log`

Data type: `Boolean`

Flag to prevent stdout log messages.
By default, all log messages are going to both stdout and to
the configured log file. With this option everything will be
going to the configured log only (unless the log file itself is stdout).

Default value: ``false``

##### <a name="no_loopback_peers"></a>`no_loopback_peers`

Data type: `Boolean`

Flag that can be used to disallow peers on the loopback addresses (127.x.x.x and ::1).
This is an extra security measure.

Default value: ``false``

##### <a name="no_multicast_peers"></a>`no_multicast_peers`

Data type: `Boolean`

Flag that can be used to disallow peers on well-known broadcast addresses (224.0.0.0 and above, and FFXX:*).
This is an extra security measure.

Default value: ``false``

##### <a name="dh2066"></a>`dh2066`

Use 2066 bits predefined DH TLS key. Default size of the key is 1066.

Default value: ``true``

##### <a name="tlsv1"></a>`tlsv1`

Data type: `Boolean`

Allow an TLS/DTLS version of protocol v1

Default value: ``false``

##### <a name="tlsv1_1"></a>`tlsv1_1`

Data type: `Boolean`

Allow an TLS/DTLS version of protocol v1.1

Default value: ``false``

##### <a name="tlsv1_2"></a>`tlsv1_2`

Data type: `Boolean`

Allow an TLS/DTLS version of protocol v1.2

Default value: ``true``

##### <a name="simple_log"></a>`simple_log`

Data type: `Boolean`

This flag means that no log file rollover will be used, and the log file
name will be constructed as-is, without PID and date appendage.
This option can be used together with the logrotate tool.

Default value: ``true``

##### <a name="proc_user"></a>`proc_user`

Data type: `String[1]`

User name to run the process, after the initialization of turnserver.

Default value: `'turnserver'`

##### <a name="proc_group"></a>`proc_group`

Data type: `String[1]`

Group name to run the process, after the initialization of turnserver.

Default value: `'turnserver'`

##### <a name="log_file"></a>`log_file`

Data type: `Optional[Variant[Stdlib::Absolutepath,Enum['syslog','stdout']]]`

Full path name of the log file or special names.
The special names are :
  * "stdout" that force everything to the stdout.
  * "syslog" that redirect everything into syslog.

Default value: `'/var/log/coturn/turnserver.log'`

